@@ -42,21 +42,21 @@ sub displayname {
 sub update{
     my $self = shift;
     my $hash = shift;
-    for(keys %$self){
+    for(grep {substr($_,0,1) ne "_"} keys %$self){
         if(exists $hash->{$_}){
             if(defined $hash->{$_} and defined $self->{$_}){
                 if($hash->{$_} ne $self->{$_}){
                     my $old_property = $self->{$_};
                     my $new_property = $hash->{$_};
                     $self->{$_} = $hash->{$_};
-                    $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property);
+                    $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property) if defined $self->{_client};
                 }
             }
             elsif( ! (!defined $hash->{$_} and !defined $self->{$_}) ){
                 my $old_property = $self->{$_};
                 my $new_property = $hash->{$_};
                 $self->{$_} = $hash->{$_};
-                $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property);
+                $self->{_client}->emit("group_member_property_change"=>$self,$_,$old_property,$new_property) if defined $self->{_client};
             }
         }
     }
